==> open-cluster-management-search-model-6.5.1-sources.jar: io/fabric8/openclustermanagement/api/model/searchoperator/v1alpha1/SearchCustomizationListFluent.java <==
package io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface SearchCustomizationListFluent<A extends SearchCustomizationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,SearchCustomization item);
  public A setToItems(Integer index,SearchCustomization item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1.SearchCustomization... items);
  public A addAllToItems(Collection<SearchCustomization> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1.SearchCustomization... items);
  public A removeAllFromItems(Collection<SearchCustomization> items);
  public A removeMatchingFromItems(Predicate<SearchCustomizationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SearchCustomization> getItems();
  public List<SearchCustomization> buildItems();
  public SearchCustomization buildItem(Integer index);
  public SearchCustomization buildFirstItem();
  public SearchCustomization buildLastItem();
  public SearchCustomization buildMatchingItem(Predicate<SearchCustomizationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<SearchCustomizationBuilder> predicate);
  public A withItems(List<SearchCustomization> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1.SearchCustomization... items);
  public Boolean hasItems();
  public SearchCustomizationListFluent.ItemsNested<A> addNewItem();
  public SearchCustomizationListFluent.ItemsNested<A> addNewItemLike(SearchCustomization item);
  public SearchCustomizationListFluent.ItemsNested<A> setNewItemLike(Integer index,SearchCustomization item);
  public SearchCustomizationListFluent.ItemsNested<A> editItem(Integer index);
  public SearchCustomizationListFluent.ItemsNested<A> editFirstItem();
  public SearchCustomizationListFluent.ItemsNested<A> editLastItem();
  public SearchCustomizationListFluent.ItemsNested<A> editMatchingItem(Predicate<SearchCustomizationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,SearchCustomizationFluent<SearchCustomizationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-search-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/searchoperator/v1alpha1/SearchCustomizationListFluent.java <==
package io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface SearchCustomizationListFluent<A extends SearchCustomizationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,SearchCustomization item);
  public A setToItems(int index,SearchCustomization item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1.SearchCustomization... items);
  public A addAllToItems(Collection<SearchCustomization> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1.SearchCustomization... items);
  public A removeAllFromItems(Collection<SearchCustomization> items);
  public A removeMatchingFromItems(Predicate<SearchCustomizationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SearchCustomization> getItems();
  public List<SearchCustomization> buildItems();
  public SearchCustomization buildItem(int index);
  public SearchCustomization buildFirstItem();
  public SearchCustomization buildLastItem();
  public SearchCustomization buildMatchingItem(Predicate<SearchCustomizationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<SearchCustomizationBuilder> predicate);
  public A withItems(List<SearchCustomization> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.searchoperator.v1alpha1.SearchCustomization... items);
  public Boolean hasItems();
  public SearchCustomizationListFluent.ItemsNested<A> addNewItem();
  public SearchCustomizationListFluent.ItemsNested<A> addNewItemLike(SearchCustomization item);
  public SearchCustomizationListFluent.ItemsNested<A> setNewItemLike(int index,SearchCustomization item);
  public SearchCustomizationListFluent.ItemsNested<A> editItem(int index);
  public SearchCustomizationListFluent.ItemsNested<A> editFirstItem();
  public SearchCustomizationListFluent.ItemsNested<A> editLastItem();
  public SearchCustomizationListFluent.ItemsNested<A> editMatchingItem(Predicate<SearchCustomizationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,SearchCustomizationFluent<SearchCustomizationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
